==> peperit_2.1_estable.zip: themes/peperit/html_files/componentes/cesta/trozos_cesta_completa/trozos_cesta_completa_acceso.php <==
<?php
//Pedro 02/Abril/2019 ==> este script muestra todo lo necesario para que el cliente haga login en la cesta:
//Vamos a recoger el resultado del registro o del login por si el cliente lo ha intentado y ha habido algún error:
$resultado_registro = Sesion::get('estado_registro', NULL);
$datos_usuario = Sesion::get('datos_usuario_registro', NULL);
$resultado_login = Sesion::get('resultado_login', 0);
$datos_login = Sesion::get('datos_login', NULL);
$usuario_inicial = ($datos_login != NULL) ? $datos_login : '';
?>
<div class="col-xs-12 col-md-10 col-md-offset-1 trozos_cesta_completa_acceso borde_contenedor">
	<div class="titulo_contenedor"><h3 class="paso1_cesta"><span class="paso_1"><strong><?=traducir('1');?></strong><?=traducir('Identifícate');?></span></h3></div>
	<div class="cuenta_si">
		<h4 class="titular titulo_opcion"><?=traducir('Con cuenta o red social');?></h4>

		<div class="acceso_cesta_login <?=($resultado_login < 0) ? ' in ' : '';?>" id="acceso_cesta_login">
			<p class="subtitulo"><?=traducir('Accede con tu email y tu contraseña');?> 
		</p>
		<?php
		if ($resultado_login == -1){
			$usuario_inicial = '';
			?>
			<div class="alert alert-danger">
				<p><?=traducir('El usuario especificado no es correcto.');?></p>
			</div>
			<?php
				}else if ($resultado_login == -2){
			?>
			<div class="alert alert-danger">
				<p><?=traducir('Contraseña incorrecta.');?></p>
			</div>
			<?php
		}
		?>
			<form action="<?=Shop::$configuracion->url;?>cesta" method="post">
				<fieldset>
					<div class="form_content clearfix">
						<div class="form-group email">
							<input class="input_formulario is_required validate account_input form-control campo_login" type="email" id="email" autocomplete="username" name="usuario" placeholder="Correo electrónico" value="<?=$usuario_inicial;?>">
							<span><i class="mdi mdi-email-outline"></i></span>
						</div>
						<div class="form-group passwd">
							<input class="input_formulario is_required validate account_input form-control campo_login" type="password" id="passwd" autocomplete="current-password" name="password" placeholder="Contraseña" value="">
							<span><i class="mdi mdi-lock-outline"></i></span>
						</div>
						<p class="lost_password form-group">
							<a href="<?=Shop::$configuracion->url;?>recuperar_pass" title="<?=traducir('Recuperar la contraseña');?>" rel="nofollow">
								<?=traducir('¿Olvidaste tu contraseña?');?>
							</a>
						</p>
						<p class="submit">
							<button type="submit" id="SubmitLogin" name="SubmitLogin" class="boton">
								<span><?=traducir('Continuar');?></span>
							</button>
						</p>
						
					</div>
					<input type="hidden" name="accion" value="login">
				</fieldset>
			</form>
		</div>
		
		
		<div class="acceso_cesta_redes_sociales">
			<div class="titulo_accede">
				<p class="subtitulo"><?=traducir('Identifícate con Google o Facebook'); ?></p>
			</div>
			<div class="iconos_redes">
				<div class="col-xs-6 google">
				<?php
				//	<div class="g-signin2" data-width="38" data-height="40" data-longtitle="true" data-onsuccess="googleCartRegister"></div>
				?>
				<div id="customBtn" class="customGPlusSignIn">
				  <a href="javascript:void(0);" ><img  class="icono_red" src="<?=Theme::findFile('google.svg', false, true);?>" border="0" alt="<?=traducir('Identificarme con cuenta de Google');?>"></a>
				</div>
				<script>
				document.addEventListener('WSLE', function(event) {
					gapi.load('auth2', function(){
						// Retrieve the singleton for the GoogleAuth library and set up the client.
						auth2 = gapi.auth2.init({
							client_id: '<?=Shop::$configuracion->google_api_id;?>',
							cookiepolicy: 'single_host_origin',
							// Request scopes in addition to 'profile' and 'email'
							//scope: 'additional_scope'
						});
						var element = document.getElementById('customBtn');
						auth2.attachClickHandler(element, {},
							function(googleUser) {
								googleCartRegister(googleUser);
							}, function(error) {
							  //El usuario ha cancelado el login
							});
					});
				});
				</script>
				</div>
				<div class="col-xs-6 facebook">
				<?php
				/*
					<div class="fb-login-button" data-width="38" data-size="medium" data-button-type="login_with" data-auto-logout-link="false" data-use-continue-as="false" scope="public_profile,email" onlogin="facebookRegister('cesta');"></div>
				*/
				?>
					<a href="javascript:fb_login();" ><img  class="icono_red" src="<?=Theme::findFile('facebook.svg', false, true);?>" border="0" alt="<?=traducir('Identificarme con Facebook');?>"></a>
				</div>
			</div>
		</div>
	</div>
	
	<div class="acceso_cesta_registro">
		<div class="col-xs-12 texto_registro">
			<h4 class="titular titulo_opcion"><?=traducir('Sin cuenta');?></h4>
			<p class="subtitulo"><?=traducir('Indícanos tus datos'); ?></p>
		<?php
			if ($resultado_registro === 0){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('Ha ocurrido un error interno al intentar realizar el registro, inténtelo de nuevo. Disculpe las molestias.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -1){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('El email introducido ya se encuentra registrado el sistema. Si ya es usuario registrado intente recuperar su contraseña.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -2){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('Las contraseñas introducidas no coinciden');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -3){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('La contraseña introducida no cumple con el patrón de seguridad obligatorio. Debe contener numeros y letras mayúsculas y minúsculas.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -4){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('No ha rellenado todos los datos obligatorios. Por favor rellene todos los campos marcados con *.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -5){
			?>
			<div class="alert alert-success">
			<p><?=traducir('Registro realizado con éxito, en breve recibirá un email en su dirección de correo con las instrucciones necesarias para verificar su identidad.');?></p>
			</div>
			<?php
			}
			?>
		</div>
		<div class="col-xs-10 col-xs-offset-1 formulario_registro">
			<form action="<?=Shop::$configuracion->url;?>cesta" method="post" class="registro_simple">
				<?=Module::insertActionController('register', 'registro_sin_password');?>
				<input type="hidden" name="redirigir_a" value="<?=Shop::$configuracion->url;?>cesta">
				<div class="account_creation">
					<fieldset>

						<div class="required form-group">
							<input type="text" class="input_formulario form-control" name="nombre" value="<?=$datos_usuario['nombre_usuario'];?>" required="required" placeholder="<?=traducir('Nombre y apellidos');?>">
						</div>

						<div class="required form-group">
							<input type="email" class="input_formulario form-control" name="email" value="<?=$datos_usuario['email_usuario'];?>" required="required" placeholder="<?=traducir('Correo electrónico');?>" autocomplete="username">
						</div>
						<div class="required form-group autorizacion">
							<p><?=traducir('¿Nos autorizas para ofrecerte productos, servicios y fidelizarte como cliente?');?></p>
							<input name="autorizacion" type="radio" required="required" class="si" name="si" value="si">
							<label class="texto_si" for="si" ><?=traducir('Sí');?></label>

							<input name="autorizacion" type="radio" required="required" class="no" name="no" value="no">
							<label class="texto_no" for="no"><?=traducir('No');?></label>
						</div>
						<div class="required form-group guardar_datos" for="desplegador_guardar_datos">
							<label class="texto_guardar" for="desplegador_guardar_datos"> 
							<input type="checkbox" class="check collapse in" id="desplegador_guardar_datos"  data-toggle="collapse" data-target="#apartado_password" onchange="$('.password_registro_cesta').toggleAttr('required', 'required');$('input[value*=\'registro\'][name^=\'accion\'').toggleAttrVal('value', 'register registro_sin_password', 'register registro');"/>

								<?=traducir('Deseo ');?><strong><?=traducir('crear');?></strong> <?=traducir(' una cuenta para futuras compras');?>
							</label>
						</div>
						
						<div class="apartado_password  collapse" id="apartado_password">
							<p class="subtitulo"><?=traducir('Introduzca una contraseña si desea guardar sus datos para futuras compras');?></p>
							<div class="required password form-group">
								<input type="password" class="input_formulario form-control password_registro_cesta" name="password" placeholder="<?= traducir('Contraseña'); ?>" autocomplete="new-password">
							</div>
							<div class="required password form-group">
								<input type="password" class="input_formulario form-control password_registro_cesta" name="password_repetido" placeholder="<?= traducir('Repetir contraseña'); ?>" autocomplete="new-password">
							</div>
						</div>
					</fieldset>
					<?php
					$grecatpcha = Module::Grecaptcha();
					echo($grecatpcha);
					?>
					<fieldset>
						<p class="submit">
							<button type="submit" name="continuar" class="boton">
								<span><?=traducir('Continuar');?></span>
							</button>
						</p>
					</fieldset>
				</div>
			</form>
		</div>
	</div>
</div>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/cesta/trozos_cesta_completa/trozos_cesta_completa_acceso.php <==
<?php
//Pedro 02/Abril/2019 ==> este script muestra todo lo necesario para que el cliente haga login en la cesta:
//Vamos a recoger el resultado del registro o del login por si el cliente lo ha intentado y ha habido algún error:
$resultado_registro = Sesion::get('estado_registro', NULL);
$datos_usuario = Sesion::get('datos_usuario_registro', NULL);
$resultado_login = Sesion::get('resultado_login', 0);
$datos_login = Sesion::get('datos_login', NULL);
$usuario_inicial = ($datos_login != NULL) ? $datos_login : '';
?>
<div class="col-xs-12 col-md-10 col-md-offset-1 trozos_cesta_completa_acceso borde_contenedor">
	<div class="titulo_contenedor"><h3 class="paso1_cesta"><span class="paso_1"><strong><?=traducir('1');?></strong><?=traducir('Identifícate');?></span></h3></div>
	<div class="cuenta_si">
		<h4 class="titular titulo_opcion"><?=traducir('Con cuenta o red social');?></h4>

		<div class="acceso_cesta_login <?=($resultado_login < 0) ? ' in ' : '';?>" id="acceso_cesta_login">
			<p class="subtitulo"><?=traducir('Accede con tu email y tu contraseña');?> 
		</p>
		<?php
		if ($resultado_login == -1){
			$usuario_inicial = '';
			?>
			<div class="alert alert-danger">
				<p><?=traducir('El usuario especificado no es correcto.');?></p>
			</div>
			<?php
				}else if ($resultado_login == -2){
			?>
			<div class="alert alert-danger">
				<p><?=traducir('Contraseña incorrecta.');?></p>
			</div>
			<?php
		}
		?>
			<form action="<?=Shop::$configuracion->url;?>cesta" method="post">
				<fieldset>
					<div class="form_content clearfix">
						<div class="form-group email">
							<input class="input_formulario is_required validate account_input form-control campo_login" type="email" id="email" autocomplete="username" name="usuario" placeholder="Correo electrónico" value="<?=$usuario_inicial;?>">
							<span><i class="mdi mdi-email-outline"></i></span>
						</div>
						<div class="form-group passwd">
							<input class="input_formulario is_required validate account_input form-control campo_login" type="password" id="passwd" autocomplete="current-password" name="password" placeholder="Contraseña" value="">
							<span><i class="mdi mdi-lock-outline"></i></span>
						</div>
						<p class="lost_password form-group">
							<a href="<?=Shop::$configuracion->url;?>recuperar_pass" title="<?=traducir('Recuperar la contraseña');?>" rel="nofollow">
								<?=traducir('¿Olvidaste tu contraseña?');?>
							</a>
						</p>
						<p class="submit">
							<button type="submit" id="SubmitLogin" name="SubmitLogin" class="boton">
								<span><?=traducir('Continuar');?></span>
							</button>
						</p>
						
					</div>
					<input type="hidden" name="accion" value="login">
				</fieldset>
			</form>
		</div>
		
		
		<div class="acceso_cesta_redes_sociales">
			<div class="titulo_accede">
				<p class="subtitulo"><?=traducir('Identifícate con Google o Facebook'); ?></p>
			</div>
			<div class="iconos_redes">
				<div class="col-xs-6 google">
				<?php
				//	<div class="g-signin2" data-width="38" data-height="40" data-longtitle="true" data-onsuccess="googleCartRegister"></div>
				?>
				<div id="customBtn" class="customGPlusSignIn">
				  <a href="javascript:void(0);" ><img  class="icono_red" src="<?=Theme::findFile('google.svg', false, true);?>" border="0" alt="<?=traducir('Identificarme con cuenta de Google');?>"></a>
				</div>
				<script>
				document.addEventListener('WSLE', function(event) {
					gapi.load('auth2', function(){
						// Retrieve the singleton for the GoogleAuth library and set up the client.
						auth2 = gapi.auth2.init({
							client_id: '<?=Shop::$configuracion->google_api_id;?>',
							cookiepolicy: 'single_host_origin',
							// Request scopes in addition to 'profile' and 'email'
							//scope: 'additional_scope'
						});
						var element = document.getElementById('customBtn');
						auth2.attachClickHandler(element, {},
							function(googleUser) {
								googleCartRegister(googleUser);
							}, function(error) {
							  //El usuario ha cancelado el login
							});
					});
				});
				</script>
				</div>
				<div class="col-xs-6 facebook">
				<?php
				/*
					<div class="fb-login-button" data-width="38" data-size="medium" data-button-type="login_with" data-auto-logout-link="false" data-use-continue-as="false" scope="public_profile,email" onlogin="facebookRegister('cesta');"></div>
				*/
				?>
					<a href="javascript:fb_login();" ><img  class="icono_red" src="<?=Theme::findFile('facebook.svg', false, true);?>" border="0" alt="<?=traducir('Identificarme con Facebook');?>"></a>
				</div>
			</div>
		</div>
	</div>
	<?php
	//Marina(18/08/2020) Compruebo si el cliente tiene marcada la opción de pedidos sin login para que no puedan hacer pedidos sin cuenta
	//si el valor de pedidos_sin_login es 1, permitiremos la opcion sin cuenta, si es 0 lo dejamos en la posibilidad de nuevo registro

	$sin_login = Shop::$configuracion->pedidos_sin_login;
	//var_dump($sin_login);
	?>
	<div class="acceso_cesta_registro">
		<div class="col-xs-12 texto_registro">
			<h4 class="titular titulo_opcion"><?=($sin_login == 0) ? traducir('Crear cuenta') : traducir('Sin cuenta');?></h4>
			<p class="subtitulo"><?=traducir('Indícanos tus datos'); ?></p>
		<?php
			if ($resultado_registro === 0){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('Ha ocurrido un error interno al intentar realizar el registro, inténtelo de nuevo. Disculpe las molestias.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -1){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('El email introducido ya se encuentra registrado el sistema. Si ya es usuario registrado intente recuperar su contraseña.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -2){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('Las contraseñas introducidas no coinciden');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -3){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('La contraseña introducida no cumple con el patrón de seguridad obligatorio. Debe contener numeros y letras mayúsculas y minúsculas.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -4){
			?>
			<div class="alert alert-danger">
			<p><?=traducir('No ha rellenado todos los datos obligatorios. Por favor rellene todos los campos marcados con *.');?></p>
			</div>
			<?php
			}else if ($resultado_registro == -5){
			?>
			<div class="alert alert-success">
			<p><?=traducir('Registro realizado con éxito, en breve recibirá un email en su dirección de correo con las instrucciones necesarias para verificar su identidad.');?></p>
			</div>
			<?php
			}
			?>
		</div>
		<div class="col-xs-10 col-xs-offset-1 formulario_registro">
			<form action="<?=Shop::$configuracion->url;?>cesta" method="post" class="registro_simple">
				<?=Module::insertActionController('register', 'registro_sin_password');?>
				<input type="hidden" name="redirigir_a" value="<?=Shop::$configuracion->url;?>cesta">
				<div class="account_creation">
					<fieldset>

						<div class="required form-group">
							<input type="text" class="input_formulario form-control" name="nombre" value="<?=$datos_usuario['nombre_usuario'];?>" required="required" placeholder="<?=traducir('Nombre y apellidos');?>">
						</div>

						<div class="required form-group">
							<input type="email" class="input_formulario form-control" name="email" value="<?=$datos_usuario['email_usuario'];?>" required="required" placeholder="<?=traducir('Correo electrónico');?>" autocomplete="username">
						</div>
						<div class="required form-group autorizacion">
							<p><?=traducir('¿Nos autorizas para ofrecerte productos, servicios y fidelizarte como cliente?');?></p>
							<?php
							$registro_sin_login_control = "$('.password_registro_cesta').toggleAttr('required', 'required');$('input[value*=\'registro\'][name^=\'accion\'').toggleAttrVal('value', 'register registro_sin_password', 'register registro');";
							?>
							<input name="autorizacion" type="radio" required="required" class="si" name="si" value="si" <?=($sin_login == 0) ? 'onchange="'.$registro_sin_login_control.'"' : '';?>>
							<label class="texto_si" for="si" ><?=traducir('Sí');?></label>

							<input name="autorizacion" type="radio" required="required" class="no" name="no" value="no" <?=($sin_login == 0) ? 'onchange="'.$registro_sin_login_control.'"' : '';?>>
							<label class="texto_no" for="no"><?=traducir('No');?></label>
						</div>

						<div class="required form-group guardar_datos" <?=($sin_login == 0) ? 'style="display:none"' : '';?> for="desplegador_guardar_datos">
							<label class="texto_guardar" for="desplegador_guardar_datos"> 
							<input type="checkbox" <?=($sin_login == 0) ? 'checked=checked' : '';?> class="check collapse in" id="desplegador_guardar_datos"  data-toggle="collapse" data-target="#apartado_password" onchange="$('.password_registro_cesta').toggleAttr('required', 'required');$('input[value*=\'registro\'][name^=\'accion\'').toggleAttrVal('value', 'register registro_sin_password', 'register registro');"/>

								<?=traducir('Deseo ');?><strong><?=traducir('crear');?></strong> <?=traducir(' una cuenta para futuras compras');?>
							</label>
						</div>
						
						<div class="apartado_password  collapse <?=($sin_login == 0) ? 'in' : '';?>" id="apartado_password">
							<p class="subtitulo" <?=($sin_login == 0) ? 'style="display:none"' : '';?>><?=traducir('Introduzca una contraseña si desea guardar sus datos para futuras compras');?></p>
							<div class="required password form-group">
								<input type="password" class="input_formulario form-control password_registro_cesta" name="password" placeholder="<?= traducir('Contraseña'); ?>" autocomplete="new-password">
							</div>
							<div class="required password form-group">
								<input type="password" class="input_formulario form-control password_registro_cesta" name="password_repetido" placeholder="<?= traducir('Repetir contraseña'); ?>" autocomplete="new-password">
							</div>
						</div>
					</fieldset>
					<?php
					$grecatpcha = Module::Grecaptcha();
					echo($grecatpcha);
					?>
					<fieldset>
						<p class="submit">
							<button type="submit" name="continuar" class="boton">
								<span><?=traducir('Continuar');?></span>
							</button>
						</p>
					</fieldset>
				</div>
			</form>
		</div>
	</div>
</div>
